
!UiTreeView methodsFor: 'rows/columns - resizing' stamp: 'mt 10/11/2010 16:20:57.432'!
setResizeModeForColumn: anIndex to: aSymbol

	(self viewport columnAt: anIndex)
		resizeMode: aSymbol.
		
	self viewport
		updateLayout;
		updateExtent.! !

!UiTreeView methodsFor: 'rows/columns - resizing' stamp: 'mt 10/11/2010 16:22:31.328'!
setWidthForColumn: anIndex to: anInteger

	| col |
	col := self viewport columnAt: anIndex.
	col resizeMode ~= #rigid
		ifTrue: [^ self].
		
	col width: anInteger.
		
	self viewport
		updateLayout;
		updateExtent.! !

!UiSimpleItemDelegate methodsFor: 'building' stamp: 'mt 10/11/2010 16:30:49.945'!
itemFor: aModelIndex

	| icon text item offset |
	icon := aModelIndex icon "ifNil: [Morph new extent: 16@16; color: Color transparent]".
	text := (aModelIndex text
		ifNil: [' ' asText asMorph lock]
		ifNotNil: [:t | t asText asMorph lock]).
	item := Morph new
		color: Color transparent;
		height: text height. "for smaller items use font height"
	
	icon ifNotNil: [item addMorphBack: icon asMorph].
	item addMorphBack: text.
	
	"Manual layouting."
	offset := item left + 3.
	item submorphs do: [:m |
		m left: offset.
		offset := offset + m width + 2.
		m top: (item top - (m height - item height // 2))].
	
	"Expand item horizontally to its contents."
	item
		width: item submorphBounds width + 10; "font rendering bugfix"
		height: item height + 1. "font rendering bugfix"
		
	^ item! !

!UiViewColumnInfo methodsFor: 'geometry' stamp: 'mt 10/11/2010 16:39:30.146'!
optimalSize
	"Return the width of the largest item."
	
	| max |
	max := 0.
	items do: [:item | 
		item hResizing ~= #spaceFill
			ifTrue: [max := max max: (item width + (item valueOfProperty: #indent))]].
	max := max max: self headerItem submorphBounds width + 10.
	^ max! !

!UiViewColumnInfo methodsFor: 'geometry' stamp: 'mt 10/11/2010 16:28:52.324'!
resize: anInteger

	super resize: anInteger.
	self headerItem width: anInteger.
	self items do: [:item | 
		item hResizing = #spaceFill
			ifTrue: [item width: self width]].! !

!UiTreeViewport methodsFor: 'rows/columns - to info' stamp: 'mt 10/11/2010 16:18:23.881'!
columnAt: index

	^ columns
		at: index
		ifAbsentPut: [UiViewColumnInfo new]! !

!UiTreeViewport methodsFor: 'drawing' stamp: 'mt 10/11/2010 16:14:39.006'!
drawSubmorphsOn: aCanvas 
	"Clip in cells. Optimized."
	
	| offset |
	submorphs isEmpty ifTrue: [^self].
	
	offset := self topLeft.
	columns withIndexDo: [:colInfo :colIndex |
		
		colInfo items withIndexDo: [:item :rowIndex | | rowInfo |
			rowInfo := rows at: rowIndex.
			aCanvas
				clipBy: (offset extent: colInfo width @ rowInfo height)
				during: [:canvas | canvas fullDrawMorph: item].
			
			offset := offset translateBy: 0 @ rowInfo height].
		
		offset := (offset x + colInfo width) @ self top].! !

!UiViewInfo methodsFor: 'initialization' stamp: 'mt 10/11/2010 16:38:47.653'!
initialize

	super initialize.
	
	items := OrderedCollection new.
	resizeMode := #shrinkWrap.
	
	self headerItem: (Morph new extent: 5@5). "dummy header item"! !

!UiViewRowInfo methodsFor: 'geometry' stamp: 'mt 10/11/2010 16:37:58.44'!
optimalSize
	"Return the height of the largest item."
	
	| max |
	max := 0.
	items do: [:item |
		item vResizing ~= #spaceFill
			ifTrue: [max := max max: item height]].
	max := max max: self headerItem submorphBounds height.
	^ max! !

!UiViewRowInfo methodsFor: 'geometry' stamp: 'mt 10/11/2010 16:29:08.358'!
resize: anInteger

	super resize: anInteger.
	self headerItem height: anInteger.
	self items do: [:item | 
		item vResizing = #spaceFill
			ifTrue: [item height: self height]].! !

!UiSmalltalkModel methodsFor: 'accessing' stamp: 'mt 10/11/2010 16:30:56.086'!
columnCountFor: aParentModelIndex
	"name, childCount, type"
	
	^ 3! !

!UiSmalltalkModel methodsFor: 'accessing - data' stamp: 'mt 10/11/2010 16:34:34.161'!
iconFor: aModelIndex

	| col package systemCategory class protocol method |
	col := aModelIndex column.
	package := aModelIndex valueOfProperty: #package ifAbsent: [].
	systemCategory := aModelIndex valueOfProperty: #systemCategory  ifAbsent: [].
	class := aModelIndex valueOfProperty: #class ifAbsent: [].
	protocol := aModelIndex valueOfProperty: #protocol ifAbsent: [].
	method := aModelIndex valueOfProperty: #method ifAbsent: [].
	
	"Horizontal headers."
	aModelIndex row = 0 ifTrue: [
		col = 1 ifTrue: [^ UiSilkIcons fontIcon].
		col = 2 ifTrue: [^ UiSilkIcons chartBarIcon].
		col = 3 ifTrue: [^ UiSilkIcons informationIcon]].
	
	package ifNotNil: [:p | 
		col = 1 ifTrue: [^ UiSilkIcons packageIcon]].
	
	"systemCategory ifNotNil: [:cat | ].
	
	class ifNotNil: [:c |].

	protocol ifNotNil: [:p | ].
	
	method ifNotNil: [:m | ]."
		
	^ nil! !

!UiSmalltalkModel methodsFor: 'accessing - data' stamp: 'mt 10/11/2010 16:35:40.297'!
textFor: aModelIndex

	| col package systemCategory class protocol method |
	col := aModelIndex column.
	package := aModelIndex valueOfProperty: #package ifAbsent: [].
	systemCategory := aModelIndex valueOfProperty: #systemCategory  ifAbsent: [].
	class := aModelIndex valueOfProperty: #class ifAbsent: [].
	protocol := aModelIndex valueOfProperty: #protocol ifAbsent: [].
	method := aModelIndex valueOfProperty: #method ifAbsent: [].
	
	"Horizontal headers."
	aModelIndex row = 0 ifTrue: [
		col = 1 ifTrue: [^ '<b>Name</b>' asHtmlText].
		col = 2 ifTrue: [^ '<b>Size</b>' asHtmlText].
		col = 3 ifTrue: [^ '<b>Type</b>' asHtmlText]].
	
	package ifNotNil: [:p | 
		col = 1 ifTrue: [^ p name].
		col = 2 ifTrue: [^ ('<font color="#555555">', p systemCategories size asString, '</font>') asHtmlText].
		col = 3 ifTrue: [^ '<font color="#555555">package</font>' asHtmlText]].
	
	systemCategory ifNotNil: [:cat | 
		| prefix |
		prefix := aModelIndex valueOfProperty: #systemCategoryPrefix.
		
		col = 2 ifTrue: [^ ('<font color="#555555">', (SystemOrganization listAtCategoryNamed: cat) size asString, '</font>') asHtmlText].
		
		cat = prefix ifFalse: [cat := cat allButFirst: prefix size + 1].
		col = 1 ifTrue: [^ cat].
		col = 3 ifTrue: [^ '<font color="#555555">system category</font>' asHtmlText]].
	
	class ifNotNil: [:c |
		col = 1 ifTrue: [^ c].
		col = 2 ifTrue: [^ ('<font color="#555555">', (Smalltalk at: c) organization categories size asString, '</font>') asHtmlText].
		col = 3 ifTrue: [^ '<font color="#555555">class</font>' asHtmlText]].

	protocol ifNotNil: [:p |
		| organization |
		organization := aModelIndex valueOfProperty: #organization.
		col = 1 ifTrue: [^ p].
		col = 2 ifTrue: [^ ('<font color="#555555">', (organization listAtCategoryNamed: p) size asString, '</font>') asHtmlText].
		col = 3 ifTrue: [^ '<font color="#555555">protocol</font>' asHtmlText]].
	
	method ifNotNil: [:m |
		col = 1 ifTrue: [^ '#', m].
		col = 3 ifTrue: [^ '<font color="#555555">method</font>' asHtmlText]].
		
	^ nil! !
